@@ -270,6 +270,108 @@ def regressione_random_forest_avanzata(df, lista_colonne_x, colonna_y, n_estimat
     return reg
 
 
+#make function to return logistic classifier model on multiple x columns
+def classificatore_logistico(df, lista_colonne_x, colonna_y):
+    from sklearn.linear_model import LogisticRegression
+    import numpy as np
+    import pandas as pd
+    import matplotlib.pyplot as plt
+    import seaborn as sns
+    import warnings
+    warnings.filterwarnings("ignore")
+    df = df.dropna()
+    X = df[lista_colonne_x]
+    X = X.values.reshape(-1,len(lista_colonne_x))
+    Y = df[colonna_y]
+    Y = Y.values.reshape(-1,1)
+    reg = LogisticRegression().fit(X, Y)
+    return reg
+
+#make function to return logistic classifier model on multiple x columns with advanced parameters
+def classificatore_logistico_avanzato(df, lista_colonne_x, colonna_y, penalty='l2', dual=False, tol=0.0001, C=1.0, fit_intercept=True, intercept_scaling=1, class_weight=None, random_state=None, solver='liblinear', max_iter=100, multi_class='ovr', verbose=0, warm_start=False, n_jobs=None):
+    from sklearn.linear_model import LogisticRegression
+    import numpy as np
+    import pandas as pd
+    import matplotlib.pyplot as plt
+    import seaborn as sns
+    import warnings
+    warnings.filterwarnings("ignore")
+    df = df.dropna()
+    X = df[lista_colonne_x]
+    X = X.values.reshape(-1,len(lista_colonne_x))
+    Y = df[colonna_y]
+    Y = Y.values.reshape(-1,1)
+    reg = LogisticRegression(penalty=penalty, dual=dual, tol=tol, C=C, fit_intercept=fit_intercept, intercept_scaling=intercept_scaling, class_weight=class_weight, random_state=random_state, solver=solver, max_iter=max_iter, multi_class=multi_class, verbose=verbose, warm_start=warm_start, n_jobs=n_jobs).fit(X, Y)
+    return reg
+
+#make function to return naive bayes model on multiple x columns
+def classificatore_naivebayes(df, lista_colonne_x, colonna_y):
+    from sklearn.naive_bayes import GaussianNB
+    import numpy as np
+    import pandas as pd
+    import matplotlib.pyplot as plt
+    import seaborn as sns
+    import warnings
+    warnings.filterwarnings("ignore")
+    df = df.dropna()
+    X = df[lista_colonne_x]
+    X = X.values.reshape(-1,len(lista_colonne_x))
+    Y = df[colonna_y]
+    Y = Y.values.reshape(-1,1)
+    reg = GaussianNB().fit(X, Y)
+    return reg
+
+#make function to return naive bayes model on multiple x columns with advanced parameters
+def classificatore_naivebayes_avanzato(df, lista_colonne_x, colonna_y, priors=None):
+    from sklearn.naive_bayes import GaussianNB
+    import numpy as np
+    import pandas as pd
+    import matplotlib.pyplot as plt
+    import seaborn as sns
+    import warnings
+    warnings.filterwarnings("ignore")
+    df = df.dropna()
+    X = df[lista_colonne_x]
+    X = X.values.reshape(-1,len(lista_colonne_x))
+    Y = df[colonna_y]
+    Y = Y.values.reshape(-1,1)
+    reg = GaussianNB(priors=priors).fit(X, Y)
+    return reg
+
+#make function to return SVM model on multiple x columns
+def classificatore_svm(df, lista_colonne_x, colonna_y):
+    from sklearn.svm import SVC
+    import numpy as np
+    import pandas as pd
+    import matplotlib.pyplot as plt
+    import seaborn as sns
+    import warnings
+    warnings.filterwarnings("ignore")
+    df = df.dropna()
+    X = df[lista_colonne_x]
+    X = X.values.reshape(-1,len(lista_colonne_x))
+    Y = df[colonna_y]
+    Y = Y.values.reshape(-1,1)
+    reg = SVC().fit(X, Y)
+    return reg
+
+#make function to return SVM model on multiple x columns with advanced parameters
+def classificatore_svm_avanzato(df, lista_colonne_x, colonna_y, C=1.0, kernel='rbf', degree=3, gamma='auto', coef0=0.0, shrinking=True, probability=False, tol=0.001, cache_size=200, class_weight=None, verbose=False, max_iter=-1, decision_function_shape='ovr', random_state=None):
+    from sklearn.svm import SVC
+    import numpy as np
+    import pandas as pd
+    import matplotlib.pyplot as plt
+    import seaborn as sns
+    import warnings
+    warnings.filterwarnings("ignore")
+    df = df.dropna()
+    X = df[lista_colonne_x]
+    X = X.values.reshape(-1,len(lista_colonne_x))
+    Y = df[colonna_y]
+    Y = Y.values.reshape(-1,1)
+    reg = SVC(C=C, kernel=kernel, degree=degree, gamma=gamma, coef0=coef0, shrinking=shrinking, probability=probability, tol=tol, cache_size=cache_size, class_weight=class_weight, verbose=verbose, max_iter=max_iter, decision_function_shape=decision_function_shape, random_state=random_state).fit(X, Y)
+    return reg
+
 #make funtion to return random forest classifier model on multiple x columns
 def classificatore_random_forest(df, lista_colonne_x, colonna_y):
     from sklearn.ensemble import RandomForestClassifier
@@ -677,6 +779,10 @@ def spiega_modello(reg, df, lista_colonne_x, colonna_y):
     warnings.filterwarnings("ignore")
     df = df.dropna()
     X = df[lista_colonne_x]
+
+    for i in range(len(lista_colonne_x)):
+        print("Feature ", i, " : ", lista_colonne_x[i])
+
     X = X.values.reshape(-1,len(lista_colonne_x))
     Y = df[colonna_y]
     Y = Y.values.reshape(-1,1)
@@ -684,3 +790,5 @@ def spiega_modello(reg, df, lista_colonne_x, colonna_y):
     shap_values = explainer.shap_values(X)
     shap.summary_plot(shap_values, X)
     shap.summary_plot(shap_values, X, plot_type='bar')
+    #waterfall plot
+    shap.waterfall_plot(explainer.expected_value, shap_values, X)
